summaryrefslogtreecommitdiffstats
path: root/ipalib/plugins/automount.py
diff options
context:
space:
mode:
authorMartin Kosek <mkosek@redhat.com>2011-02-02 17:15:35 +0100
committerRob Crittenden <rcritten@redhat.com>2011-02-02 15:38:50 -0500
commit0353a2be677594125892e16fe0cdebe264d2ccb2 (patch)
tree207c512050aec52000b8179098b68d98a3f96974 /ipalib/plugins/automount.py
parentbb56285f6b350fcdd7b22f6d6c4fb69da5ce438d (diff)
downloadfreeipa-0353a2be677594125892e16fe0cdebe264d2ccb2.tar.gz
freeipa-0353a2be677594125892e16fe0cdebe264d2ccb2.tar.xz
freeipa-0353a2be677594125892e16fe0cdebe264d2ccb2.zip
Typos in freeIPA messages
This patch fixes several reported typos in IPA messages and in comments. Contributors file has been updated + the original author of the patch reporting the typos was added. https://fedorahosted.org/freeipa/ticket/848
Diffstat (limited to 'ipalib/plugins/automount.py')
-rw-r--r--ipalib/plugins/automount.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/ipalib/plugins/automount.py b/ipalib/plugins/automount.py
index ec306ac71..9c2c0ad13 100644
--- a/ipalib/plugins/automount.py
+++ b/ipalib/plugins/automount.py
@@ -67,7 +67,7 @@ Locations:
ipa automountlocation-import baltimore /etc/auto.master
The import will fail if any duplicate entries are found. For
continous operation where errors are ignored use the --continue
option.
Maps:
@@ -318,7 +318,7 @@ class automountlocation_import(LDAPQuery):
takes_options = (
Flag('continue?',
cli_name='continue',
- doc=_('Continous operation mode. Errors are reported but the process continues'),
+ doc=_('Continuous operation mode. Errors are reported but the process continues'),
),
)
@@ -67,7 +67,7 @@ Locations:
ipa automountlocation-import baltimore /etc/auto.master
The import will fail if any duplicate entries are found. For
- continous operation where errors are ignored use the --continue
+ continuous operation where errors are ignored use the --continue
option.
Maps: